Module session
kellnr_
web_
ui
6.2.0
Module session
Module Items
Structs
Enums
Traits
Functions
In crate kellnr_
web_
ui
kellnr_web_ui
Module
session
Structs

Admin
User
AnyUser
Normal
User
Enums

Maybe
User
Traits

Name
Functions

session_
auth_
when_
required
Middleware that checks if a user is logged in when
settings.registry.auth_required
is
true
If the user is not logged in, a 401 is returned.